==> vue-fall-menu-2.8.0.tgz: package/lib/pc.js <==
import { renderless, api } from "@dft-vue-2-opentiny/vue-renderless/fall-menu/vue";
import { defineComponent, props, setup as _setup } from "@dft-vue-2-opentiny/vue-common";
import Row from "@dft-vue-2-opentiny/vue-row";
import Col from "@dft-vue-2-opentiny/vue-col";
import { iconChevronLeft, iconChevronRight } from "@dft-vue-2-opentiny/vue-icon";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  emits: ["hook-updated"],
  props: [].concat(props, ["data"]),
  components: {
    TinyRow: Row,
    TinyCol: Col,
    IconChevronLeft: iconChevronLeft(),
    IconChevronRight: iconChevronRight()
  },
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-fall-menu"
  }, [_c("div", {
    staticClass: "tiny-fall-menu__wrap"
  }, [_c("div", {
    staticClass: "tiny-fall-menu__nav"
  }, [_c("div", {
    staticClass: "tiny-fall-menu__subnav"
  }, [_c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.pager != 1,
      expression: "state.pager != 1"
    }],
    staticClass: "icon-slot-left",
    on: {
      "click": function click($event) {
        return _vm.arrowClick(-1);
      }
    }
  }, [_vm._t("left", [_c("icon-chevron-left", {
    staticClass: "tiny-svg-size"
  })])], 2), _c("div", {
    ref: "list",
    staticClass: "tiny-fall-menu__list",
    style: {
      left: _vm.state.left
    }
  }, [_c("ul", _vm._l(_vm.state.data, function(level1, index) {
    return _c("li", {
      key: index,
      class: {
        "fall-hide": index >= _vm.state.pagerData.index[_vm.state.pager - 1] && _vm.state.pager !== _vm.state.pagerData.size
      },
      on: {
        "mouseover": function mouseover($event) {
          return _vm.mouseover(index);
        },
        "mouseout": _vm.mouseout
      }
    }, [_vm._t("level1", [_c("a", {
      class: {
        now: index === _vm.state.activeNode
      },
      attrs: {
        "href": level1.url
      }
    }, [_vm._v(_vm._s(level1.title) + " ")])], {
      "slotScope": level1
    })], 2);
  }), 0)]), _c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.pager !== _vm.state.pagerData.size,
      expression: "state.pager !== state.pagerData.size"
    }],
    staticClass: "icon-slot-right",
    on: {
      "click": function click($event) {
        return _vm.arrowClick(1);
      }
    }
  }, [_vm._t("right", [_c("icon-chevron-right", {
    staticClass: "tiny-svg-size"
  })])], 2)]), _c("tiny-row", [_c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.isActive,
      expression: "state.isActive"
    }],
    ref: "fall",
    staticClass: "tiny-fall-menu__box",
    class: {
      active: _vm.state.isActive
    },
    on: {
      "mouseover": function mouseover($event) {
        return _vm.overContent(true);
      },
      "mouseout": function mouseout($event) {
        return _vm.overContent(false);
      }
    }
  }, [_c("div", {
    staticClass: "contbox"
  }, _vm._l(_vm.state.level2data, function(level2, index) {
    return _c("tiny-col", {
      key: index,
      staticClass: "cont",
      attrs: {
        "xs": 6,
        "sm": 3,
        "md": 3,
        "lg": 3,
        "xl": 2
      }
    }, [_c("ul", {
      staticClass: "sublist clearfix"
    }, [_c("li", [_c("h3", {
      staticClass: "mcate-item-hd"
    }, [_vm._t("level2", [_c("span", [_vm._v(_vm._s(level2.title))])], {
      "slotScope": level2
    })], 2), _c("p", {
      staticClass: "mcate-item-bd"
    }, [_vm._t("level3", _vm._l(level2.children, function(level3, index2) {
      return _c("a", {
        key: index2,
        attrs: {
          "href": level3.url
        }
      }, [_vm._v(_vm._s(level3.title))]);
    }), {
      "slotScope": level2.children
    })], 2)])])]);
  }), 1)])])], 1)])]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  pc as default
};

==> vue-fall-menu-2.22.0.tgz: package/lib/pc.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/fall-menu/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import Row from '@opentinyvue/vue-row';
import Col from '@opentinyvue/vue-col';
import { iconChevronLeft, iconChevronRight } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  props: [].concat(props, ["data"]),
  components: {
    TinyRow: Row,
    TinyCol: Col,
    IconChevronLeft: iconChevronLeft(),
    IconChevronRight: iconChevronRight()
  },
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-fall-menu"
  }, [_c("div", {
    staticClass: "tiny-fall-menu__wrap"
  }, [_c("div", {
    staticClass: "tiny-fall-menu__nav"
  }, [_c("div", {
    staticClass: "tiny-fall-menu__subnav"
  }, [_c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.pager !== 1,
      expression: "state.pager !== 1"
    }],
    staticClass: "icon-slot-left",
    on: {
      "click": function click($event) {
        return _vm.arrowClick(-1);
      }
    }
  }, [_vm._t("left", function() {
    return [_c("icon-chevron-left", {
      staticClass: "tiny-svg-size"
    })];
  })], 2), _c("div", {
    ref: "list",
    staticClass: "tiny-fall-menu__list",
    style: {
      left: _vm.state.left
    }
  }, [_c("ul", _vm._l(_vm.state.data, function(level1, index) {
    return _c("li", {
      key: index,
      class: [index >= _vm.state.pagerData.index[_vm.state.pager - 1] && _vm.state.pager !== _vm.state.pagerData.size ? "fall-hide" : ""],
      on: {
        "click": function click($event) {
          return _vm.clickActive(index);
        },
        "mouseover": function mouseover($event) {
          return _vm.mouseover(index);
        },
        "mouseout": _vm.mouseout
      }
    }, [_vm._t("level1", function() {
      return [_c("a", {
        class: [index === _vm.state.active ? "active-show" : "", index === _vm.state.activeNode ? "now" : ""],
        attrs: {
          "href": level1.url
        }
      }, [_vm._v(_vm._s(level1.title) + " ")])];
    }, {
      "slotScope": level1
    })], 2);
  }), 0)]), _c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.pager !== _vm.state.pagerData.size,
      expression: "state.pager !== state.pagerData.size"
    }],
    staticClass: "icon-slot-right",
    on: {
      "click": function click($event) {
        return _vm.arrowClick(1);
      }
    }
  }, [_vm._t("right", function() {
    return [_c("icon-chevron-right", {
      staticClass: "tiny-svg-size"
    })];
  })], 2)]), _c("tiny-row", [_c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.isActive,
      expression: "state.isActive"
    }],
    ref: "fall",
    staticClass: "tiny-fall-menu__box",
    class: {
      active: _vm.state.isActive
    },
    on: {
      "mouseover": function mouseover($event) {
        return _vm.overContent(true);
      },
      "mouseout": function mouseout($event) {
        return _vm.overContent(false);
      }
    }
  }, [_c("div", {
    staticClass: "contbox"
  }, _vm._l(_vm.state.level2data, function(level2, index) {
    return _c("tiny-col", {
      key: index,
      staticClass: "cont",
      attrs: {
        "xs": 6,
        "sm": 3,
        "md": 3,
        "lg": 3,
        "xl": 2
      }
    }, [_c("ul", {
      staticClass: "sublist clearfix"
    }, [_c("li", [_c("h3", {
      staticClass: "mcate-item-hd"
    }, [_vm._t("level2", function() {
      return [_c("span", [_vm._v(_vm._s(level2.title))])];
    }, {
      "slotScope": level2
    })], 2), _c("p", {
      staticClass: "mcate-item-bd"
    }, [_vm._t("level3", function() {
      return _vm._l(level2.children, function(level3, index3) {
        return _c("a", {
          key: index3,
          attrs: {
            "href": level3.url
          }
        }, [_vm._v(_vm._s(level3.title))]);
      });
    }, {
      "slotScope": level2.children
    })], 2)])])]);
  }), 1)])])], 1)])]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
